# == Class: skype
#
# Puppet module to install Skype on Fedora.
#
# === Parameters
#
# [$version]
#   Define Skype Version
#
# === Variables
#
# [$download_link]
#   Link to Skype tarball.
#
# [$install_cmd]
#   Download und extract command
#
# [$cleanup_cmd]
#   Remove files under $install_dir
#
# === Examples
#
#  class { 'skype':
#    version => '4.3.0.37'
#  }
#
# === Authors
#
# Marius Preyers
#
class skype ( $version = '4.3.0.37' ) {
 
  $install_dir   = '/opt/skype'
  $download_link = "http://download.skype.com/linux/skype-$version.tar.bz2"
  $install_cmd   = "curl -s $download_link | tar xjf - -C $install_dir --strip-components=1"
  $cleanup_cmd   = "find $install_dir -maxdepth 1 ! -path $install_dir ! -name PUPPET -exec rm -rf {} +"

  include skype::deps

  file { "$install_dir":
    ensure => directory,
    mode   => 0755
  }

  file { "$install_dir/PUPPET":
    mode    => 0644,
    content => "\$version = '$version'\n",
    require => File["$install_dir"],
    notify  => Exec["$cleanup_cmd"]
  }

  exec { "$cleanup_cmd":
    path        => '/bin',
    refreshonly => true,
    notify      => Exec["$install_cmd"]
  }

  exec { "$install_cmd":
    path        => '/usr/bin',
    refreshonly => true,
    require     => Package['curl']
  }

  file { '/usr/share/applications/skype.desktop':
    ensure  => link,
    target  => "$install_dir/skype.desktop",
    require => Exec["$install_cmd"]
  }

  file { '/usr/share/icons/skype.png':
    ensure  => link,
    target  => "$install_dir/icons/SkypeBlue_256x256.png",
    require => Exec["$install_cmd"]
  }

  file { '/usr/share/pixmaps/skype.png':
    ensure  => link,
    target  => "$install_dir/icons/SkypeBlue_256x256.png",
    require => Exec["$install_cmd"]
  }

  file { '/usr/bin/skype':
    mode    => 0755,
    content => template('skype/skype-wrapper.erb'),
    require => Exec["$install_cmd"]
  }

}
